@@ -36,7 +36,6 @@
 #'  .R                     = 499, 
 #'  .saturated             = FALSE,
 #'  .seed                  = NULL,
-#'  .verbose               = TRUE,
 #'  ...
 #' )
 #' 
@@ -70,7 +69,6 @@ testOMF <- function(
   .R                     = 499, 
   .saturated             = FALSE,
   .seed                  = NULL,
-  .verbose               = TRUE,
   ...
 ) {
   
@@ -97,7 +95,6 @@ testOMF <- function(
                   .R                    = .R,
                   .saturated            = .saturated,
                   .seed                 = .seed,
-                  .verbose              = .verbose,
                   ...
     )
     ## Return
@@ -124,11 +121,6 @@ testOMF <- function(
     )
   }
   
-  # if(.verbose) {
-  #   cat(rule2("Test for overall model fit based on Beran & Srivastava (1985)",
-  #             type = 3), "\n\n")
-  # }
-  
   ### Checks and errors ========================================================
   ## Check if initial results are inadmissible
   if(sum(unlist(verify(.object))) != 0) {
@@ -156,12 +148,14 @@ testOMF <- function(
   ## Calculate test statistic
   if(.fit_measures) {
     teststat <- c(
-      "dG"           = calculateDG(.object),
-      "SRMR"         = calculateSRMR(.object),
-      "dL"           = calculateDL(.object),
-      "dML"          = calculateDML(.object),
-      "Chi_square"   = calculateChiSquare(.object),
-      "Chi_square_df"= calculateChiSquareDf(.object),
+      "dG"           = calculateDG(.object,.saturated = .saturated),
+      "SRMR"         = calculateSRMR(.object,.saturated = .saturated),
+      "dL"           = calculateDL(.object,.saturated = .saturated),
+      "dML"          = calculateDML(.object,.saturated = .saturated),
+      "Chi_square"   = calculateChiSquare(.object,.saturated = .saturated),
+      # The following fit measures are not affected by the saturated argument since they are based on dfs,
+      # which calculation is a bit more more difficult in case of a saturated structural model. 
+      "Chi_square_df"= calculateChiSquareDf(.object), 
       "CFI"          = calculateCFI(.object),
       "GFI"          = calculateGFI(.object,...),
       "IFI"          = calculateIFI(.object),
@@ -173,10 +167,10 @@ testOMF <- function(
     )
   } else {
     teststat <- c(
-      "dG"           = calculateDG(.object),
-      "SRMR"         = calculateSRMR(.object),
-      "dL"           = calculateDL(.object),
-      "dML"          = calculateDML(.object)
+      "dG"           = calculateDG(.object,.saturated = .saturated),
+      "SRMR"         = calculateSRMR(.object,.saturated = .saturated),
+      "dL"           = calculateDL(.object,.saturated = .saturated),
+      "dML"          = calculateDML(.object,.saturated = .saturated)
     )
   }
 
@@ -255,11 +249,13 @@ testOMF <- function(
         
        ref_dist[[counter]] <- if(.fit_measures) {
         c(
-          "dG"           = calculateDG(Est_temp),
-          "SRMR"         = calculateSRMR(Est_temp),
-          "dL"           = calculateDL(Est_temp),
-          "dML"          = calculateDML(Est_temp),
-          "Chi_square"   = calculateChiSquare(Est_temp),
+          "dG"           = calculateDG(Est_temp,.saturated = .saturated),
+          "SRMR"         = calculateSRMR(Est_temp,.saturated = .saturated),
+          "dL"           = calculateDL(Est_temp,.saturated = .saturated),
+          "dML"          = calculateDML(Est_temp,.saturated = .saturated),
+          "Chi_square"   = calculateChiSquare(Est_temp,.saturated = .saturated),
+          # The following fit measures are not affected by the saturated argument since they are based on dfs,
+          # which calculation is a bit more more difficult in case of a saturated structural model. 
           "Chi_square_df"= calculateChiSquareDf(Est_temp),
           "CFI"          = calculateCFI(Est_temp),
           "GFI"          = calculateGFI(Est_temp,...),
@@ -272,10 +268,10 @@ testOMF <- function(
         ) 
       } else {
         c(
-          "dG"           = calculateDG(Est_temp),
-          "SRMR"         = calculateSRMR(Est_temp),
-          "dL"           = calculateDL(Est_temp),
-          "dML"          = calculateDML(Est_temp)
+          "dG"           = calculateDG(Est_temp,.saturated = .saturated),
+          "SRMR"         = calculateSRMR(Est_temp,.saturated = .saturated),
+          "dL"           = calculateDL(Est_temp,.saturated = .saturated),
+          "dML"          = calculateDML(Est_temp,.saturated = .saturated)
         ) 
       }
         
@@ -361,7 +357,8 @@ testOMF <- function(
       "Bootstrap_values"   = ref_dist,
       "Number_admissibles" = ncol(ref_dist_matrix),
       "Seed"               = .seed,
-      "Total_runs"         = counter + n_inadmissibles
+      "Total_runs"         = counter + n_inadmissibles,
+      "Saturated"          = .saturated
     )
   )
   
